# Sientia Log Library
Library for users to log information through SIENTIA™ <br />

Documentation for the library can be found [here](https://psychic-waddle-7kwrrmw.pages.github.io/) (Work in Progress)
